#include <cuda.h>
#include <stdio.h>
#include <string.h>

#define	VER_MAJOR	0
#define	VER_MINOR	1

int main(int argc,char *argv[])
{
	int device, deviceCount;
    char name[256] = {0};
    if((argc == 2) && (!strcmp(argv[1],"--version") || !strcmp(argv[1],"-v")))
    {
    	printf("%s version %d.%d\n",argv[0],VER_MAJOR,VER_MINOR);
    	return 0;
    }
	cuInit(0);
	cuDeviceGetCount(&deviceCount);
	if(deviceCount < 1)
	{
		puts("No CUDA-capable device found");
		return -1;
	}
	for(device = 0; device < deviceCount; ++device)
	{
		CUdevice cuDevice;
		int major, minor, memtotal;
		CUdevprop prop;
		cuDeviceGet(&cuDevice, device);
		cuDeviceComputeCapability(&major, &minor, cuDevice);
		cuDeviceTotalMem(&memtotal, cuDevice);
		cuDeviceGetProperties(&prop,cuDevice);
        cuDeviceGetName(name,256,cuDevice);
		if(!memtotal)
		{
			puts("OOPS! It seems you have started this app from FS text console.");
			break;
		}
		printf("Device #%i (%s):\n"
			"CUDA ver. %d.%d\n"
			"Total memory %d Mb (%d bytes)\n"
			"maxThreadsPerBlock %d\n"
			"maxThreadsDim (%d,%d,%d)\n"
			"maxGridSize (%d,%d,%d)\n"
			"sharedMemPerBlock %08X (%d)\n"
			"totalConstantMemory %08X (%d)\n"
			"SIMDWidth %d\n"
			"memPitch %08X (%d)\n"
			"regsPerBlock %d\n"
			"clockRate %d kHz\n"
			"textureAlign %d\n",
			device, name, major, minor,
			memtotal >> 20,memtotal,
			prop.maxThreadsPerBlock,
			prop.maxThreadsDim[0],prop.maxThreadsDim[1],prop.maxThreadsDim[2],
			prop.maxGridSize[0],prop.maxGridSize[1],prop.maxGridSize[2],
			prop.sharedMemPerBlock,prop.sharedMemPerBlock,
			prop.totalConstantMemory,prop.totalConstantMemory,
			prop.SIMDWidth,
			prop.memPitch,prop.memPitch,
			prop.regsPerBlock,
			prop.clockRate,
			prop.textureAlign);
	}
	return 0;
}
